@@ -297,10 +297,10 @@ QuickTimeFileSink::QuickTimeFileSink(UsageEnvironment& env,
   }
 
   // Use the current time as the file's creation and modification
-  // time.  Use Apple's time format: seconds since January 1, 1904
+  // time.  Use Apple's time format: seconds (UTC) since January 1, 1904
 
   gettimeofday(&fStartTime, NULL);
-  fAppleCreationTime = fStartTime.tv_sec - 0x83dac000;
+  fAppleCreationTime = fStartTime.tv_sec - 0x83da4f80;
 
   // Begin by writing a "mdat" atom at the start of the file.
   // (Later, when we've finished copying data to the file, we'll come
@@ -711,16 +711,18 @@ void SubsessionIOState::afterGettingFrame(unsigned packetDataSize,
 					  struct timeval presentationTime) {
   // Begin by checking whether there was a gap in the RTP stream.
   // If so, try to compensate for this (if desired):
-  unsigned short rtpSeqNum
-    = fOurSubsession.rtpSource()->curPacketRTPSeqNum();
-  if (fOurSink.fPacketLossCompensate && fPrevBuffer->bytesInUse() > 0) {
-    short seqNumGap = rtpSeqNum - fLastPacketRTPSeqNum;
-    for (short i = 1; i < seqNumGap; ++i) {
-      // Insert a copy of the previous frame, to compensate for the loss:
-      useFrame(*fPrevBuffer);
+  if (fOurSubsession.rtpSource() != NULL) { // we have a RTP stream
+    unsigned short rtpSeqNum
+      = fOurSubsession.rtpSource()->curPacketRTPSeqNum();
+    if (fOurSink.fPacketLossCompensate && fPrevBuffer->bytesInUse() > 0) {
+      short seqNumGap = rtpSeqNum - fLastPacketRTPSeqNum;
+      for (short i = 1; i < seqNumGap; ++i) {
+	// Insert a copy of the previous frame, to compensate for the loss:
+	useFrame(*fPrevBuffer);
+      }
     }
+    fLastPacketRTPSeqNum = rtpSeqNum;
   }
-  fLastPacketRTPSeqNum = rtpSeqNum;
 
   // Now, continue working with the frame that we just got
   fOurSink.noteRecordedFrame(fOurSubsession, packetDataSize, presentationTime);
@@ -732,7 +734,8 @@ void SubsessionIOState::afterGettingFrame(unsigned packetDataSize,
 
   // If our RTP source is a "QuickTimeGenericRTPSource", then
   // use its 'qtState' to set some parameters that we need:
-  if (fQTMediaDataAtomCreator == &QuickTimeFileSink::addAtom_genericMedia){
+  if (fOurSubsession.rtpSource() != NULL // we have a RTP stream
+      && fQTMediaDataAtomCreator == &QuickTimeFileSink::addAtom_genericMedia) {
     QuickTimeGenericRTPSource* rtpSource
       = (QuickTimeGenericRTPSource*)fOurSubsession.rtpSource();
     QuickTimeGenericRTPSource::QTState& qtState = rtpSource->qtState;
@@ -851,13 +854,12 @@ void SubsessionIOState::useFrame(SubsessionBuffer& buffer) {
   // Write the data into the file:
   fwrite(frameSource, 1, frameSize, fOurSink.fOutFid);
 
-  // If we have a hint track, then write to it also:
-  if (hasHintTrack()) {
+  // If we have a hint track, then write to it also (only if we have a RTP stream):
+  if (hasHintTrack() && fOurSubsession.rtpSource() != NULL) {
     // Because presentation times are used for RTP packet timestamps,
     // we don't starting writing to the hint track until we've been synced:
     if (!fHaveBeenSynced) {
-      fHaveBeenSynced
-	= fOurSubsession.rtpSource()->hasBeenSynchronizedUsingRTCP();
+      fHaveBeenSynced = fOurSubsession.rtpSource()->hasBeenSynchronizedUsingRTCP();
     }
     if (fHaveBeenSynced) {
       fHintTrackForUs->useFrameForHinting(frameSize, presentationTime,
@@ -884,7 +886,7 @@ void SubsessionIOState::useFrameForHinting(unsigned frameSize,
   // If there has been a previous frame, then output a 'hint sample' for it.
   // (We use the current frame's presentation time to compute the previous
   // hint sample's duration.)
-  RTPSource* const rs = fOurSubsession.rtpSource(); // abbrev
+  RTPSource* const rs = fOurSubsession.rtpSource(); // abbrev (ASSERT: != NULL)
   struct timeval const& ppt = fPrevFrameState.presentationTime; //abbrev
   if (ppt.tv_sec != 0 || ppt.tv_usec != 0) {
     double duration = (presentationTime.tv_sec - ppt.tv_sec)
@@ -1102,7 +1104,7 @@ void SubsessionIOState::onSourceClosure() {
 
 Boolean SubsessionIOState::syncOK(struct timeval presentationTime) {
   QuickTimeFileSink& s = fOurSink; // abbreviation
-  if (!s.fSyncStreams) return True; // we don't care
+  if (!s.fSyncStreams || fOurSubsession.rtpSource() == NULL) return True; // we don't care
 
   if (s.fNumSyncedSubsessions < s.fNumSubsessions) {
     // Not all subsessions have yet been synced.  Check whether ours was
@@ -1675,10 +1677,13 @@ unsigned QuickTimeFileSink::addAtom_genericMedia() {
   // Use its "sdAtom" state for our contents:
   QuickTimeGenericRTPSource* rtpSource = (QuickTimeGenericRTPSource*)
     fCurrentIOState->fOurSubsession.rtpSource();
-  QuickTimeGenericRTPSource::QTState& qtState = rtpSource->qtState;
-  char const* from = qtState.sdAtom;
-  unsigned size = qtState.sdAtomSize;
-  for (unsigned i = 0; i < size; ++i) addByte(from[i]);
+  unsigned size = 0;
+  if (rtpSource != NULL) {
+    QuickTimeGenericRTPSource::QTState& qtState = rtpSource->qtState;
+    char const* from = qtState.sdAtom;
+    size = qtState.sdAtomSize;
+    for (unsigned i = 0; i < size; ++i) addByte(from[i]);
+  }
 addAtomEnd;
 
 unsigned QuickTimeFileSink::addAtom_soundMediaGeneral() {
@@ -2314,15 +2319,17 @@ addAtomEnd;
 addAtom(payt);
   MediaSubsession& ourSubsession = fCurrentIOState->fOurSubsession;
   RTPSource* rtpSource = ourSubsession.rtpSource();
-  size += addWord(rtpSource->rtpPayloadFormat());
+  if (rtpSource != NULL) {
+    size += addWord(rtpSource->rtpPayloadFormat());
 
-  // Also, add a 'rtpmap' string: <mime-subtype>/<rtp-frequency>
-  unsigned rtpmapStringLength = strlen(ourSubsession.codecName()) + 20;
-  char* rtpmapString = new char[rtpmapStringLength];
-  sprintf(rtpmapString, "%s/%d",
-	  ourSubsession.codecName(), rtpSource->timestampFrequency());
-  size += addArbitraryString(rtpmapString);
-  delete[] rtpmapString;
+    // Also, add a 'rtpmap' string: <mime-subtype>/<rtp-frequency>
+    unsigned rtpmapStringLength = strlen(ourSubsession.codecName()) + 20;
+    char* rtpmapString = new char[rtpmapStringLength];
+    sprintf(rtpmapString, "%s/%d",
+	    ourSubsession.codecName(), rtpSource->timestampFrequency());
+    size += addArbitraryString(rtpmapString);
+    delete[] rtpmapString;
+  }
 addAtomEnd;
 
 // A dummy atom (with name "????"):
